/*
 *  TOPPERS/ASP Kernel
 *      Toyohashi Open Platform for Embedded Real-Time Systems/
 *      Advanced Standard Profile Kernel
 *
 *  Copyright (C) 2013-2014 by Embedded and Real-Time Systems Laboratory
 *              Graduate School of Information Science, Nagoya Univ., JAPAN
 *  Copyright (C) 2018 by Naoki Saito
 *             Nagoya Municipal Industrial Research Institute, JAPAN
 *
 *  上記著作権者は，以下の(1)〜(4)の条件を満たす場合に限り，本ソフトウェ
 *  ア（本ソフトウェアを改変したものを含む．以下同じ）を使用・複製・改
 *  変・再配布（以下，利用と呼ぶ）することを無償で許諾する．
 *  (1) 本ソフトウェアをソースコードの形で利用する場合には，上記の著作
 *      権表示，この利用条件および下記の無保証規定が，そのままの形でソー
 *      スコード中に含まれていること．
 *  (2) 本ソフトウェアを，ライブラリ形式など，他のソフトウェア開発に使
 *      用できる形で再配布する場合には，再配布に伴うドキュメント（利用
 *      者マニュアルなど）に，上記の著作権表示，この利用条件および下記
 *      の無保証規定を掲載すること．
 *  (3) 本ソフトウェアを，機器に組み込むなど，他のソフトウェア開発に使
 *      用できない形で再配布する場合には，次のいずれかの条件を満たすこ
 *      と．
 *    (a) 再配布に伴うドキュメント（利用者マニュアルなど）に，上記の著
 *        作権表示，この利用条件および下記の無保証規定を掲載すること．
 *    (b) 再配布の形態を，別に定める方法によって，TOPPERSプロジェクトに
 *        報告すること．
 *  (4) 本ソフトウェアの利用により直接的または間接的に生じるいかなる損
 *      害からも，上記著作権者およびTOPPERSプロジェクトを免責すること．
 *      また，本ソフトウェアのユーザまたはエンドユーザからのいかなる理
 *      由に基づく請求からも，上記著作権者およびTOPPERSプロジェクトを
 *      免責すること．
 *
 *  本ソフトウェアは，無保証で提供されているものである．上記著作権者お
 *  よびTOPPERSプロジェクトは，本ソフトウェアに関して，特定の使用目的
 *  に対する適合性も含めて，いかなる保証も行わない．また，本ソフトウェ
 *  アの利用により直接的または間接的に生じたいかなる損害に関しても，そ
 *  の責任を負わない．
 *
 *  $Id$
 */

/*
 *  QEMU VIRT ターゲットのハードウェア資源定義
 */

#ifndef TOPPERS_QEMU_VIRT_H
#define TOPPERS_QEMU_VIRT_H

/*
 *  割込み番号（intno）の定義
 */
#define TINTNO_TIMER    27    /* 高分解能タイマ */
#define TINTNO_UART0    33    /* SIOポート */

/*
 * GIC
 */
#define GIC_BASE                (0x08000000)
#define GICD_BASE               (GIC_BASE)
#define GICC_BASE               (GIC_BASE + 0x10000)
#define GIC_TNUM_INTNO          (64)

/*
 *  割込み番号の最小値と最大値
 */
#define TMIN_INTNO              UINT_C(0)
#define TMAX_INTNO              (GIC_TNUM_INTNO - 1)

/*
 *  UARTレジスタのベースアドレス
 */
#define VIRT_UART0_BASE		(0x09000000)

/*
 *  ボーレート設定（38400bps）
 */
#define VIRT_UART_IBRD_38400	0x27U
#define VIRT_UART_FBRD_38400	0x04U

#ifndef  TOPPERS_MACRO_ONLY
#endif  /*  TOPPERS_MACRO_ONLY  */
#endif /* TOPPERS_QEMU_VIRT_H */
